==> pkg_add_it-1.3.tar.gz: pkg_add_it-1.3/pkg.h <==
/*-
 * Copyright (c) 2010  Marin Atanasov Nikolov  <dnaeon@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _PKG_H_
#define _PKG_H_

#ifndef _SYS_QUEUE_H_
#include <sys/queue.h>
#endif

#define LONGLINE		 "#####################################################################\n"

#define PKG_DB_PATH		 "/var/db/pkg"
#define PKG_DISPLAY_FILE	 "+DISPLAY"

#define PKG_EXTENSION		 ".tbz"
#define PKG_FIELDS_SEPARATOR	 "|"

#define PKG_FIELDS		 13

/* package fields */
#define PKG_NAME		 0	 /* package name */
#define PKG_PORT_DIR		 1	 /* package port directory */
#define PKG_INST_PREFIX		 2	 /* package install prefix */
#define PKG_DESC		 3	 /* package description */
#define PKG_DESC_FILE		 4	 /* package description file location */
#define PKG_MAINT		 5	 /* package maintainer */
#define PKG_CAT			 6	 /* package category/path */
#define PKG_BDEPS		 7	 /* package build-deps */
#define PKG_RDEPS		 8	 /* package run-deps */ 
#define PKG_WWW			 9	 /* package web site */
#define PKG_EDEPS		 10	 /* package extract-deps */
#define PKG_PDEPS		 11	 /* package patch-deps */
#define PKG_FDEPS		 12	 /* package fetch-deps */

/* package fields headers */
#define PKG_NAME_HEADER		 "Name: "
#define PKG_PORT_DIR_HEADER	 "Port: "
#define PKG_INST_PREFIX_HEADER	 "Install prefix: "
#define PKG_DESC_HEADER		 "Description: "
#define PKG_DESC_FILE_HEADER	 "Description file: "
#define PKG_MAINT_HEADER	 "Maintainer: "
#define PKG_CAT_HEADER		 "Category: "
#define PKG_BDEPS_HEADER	 "B-Deps: "
#define PKG_RDEPS_HEADER	 "R-Deps: "
#define PKG_WWW_HEADER		 "WWW: "
#define PKG_EDEPS_HEADER	 "E-Deps: "
#define PKG_PDEPS_HEADER	 "P-Deps: "
#define PKG_FDEPS_HEADER	 "F-Deps: "

/* package state flags */
#define PKG_FLAGS_INSTALLED	 0x00000001
#define PKG_FLAGS_INSTALL_RESULT 0x00000002
#define PKG_FLAGS_SELECTED	 0x00000004
#define PKG_FLAGS_COPIED	 0x00000008

/* indent of package dependencies while listing them in a tree view */ 
#define PKG_DEPS_INDENT		 4
#define PKG_DEPS_INDENT_CHAR     ' '
#define PKG_DEPS_INDENT_LINK	 '|'

/* 
 * stores the information for each package 
 *
 * pkg_fields[] - all data describing a package
 * deps_head    - tail containing the package dependencies
 * pkg_num      - number of packages in the category (used only with the -C option)
 * flags        - stores information about the following package states:
 *		  - package is already installed
 *		  - result from package installation - success or failure
 *		  - package is already selected for install by a previous package
 */ 

typedef struct pkg {
   char	   *pkg_fields[PKG_FIELDS];
   char	    flags;
   unsigned pkg_num; 

   STAILQ_ENTRY(pkg) entries;
   STAILQ_HEAD(, pkg) deps_head;
} PKG;

void  pkg_build_deps_full_tree(PKG *pkg_entry);
void  pkg_choose(int num_pkgs);
int   pkg_deps_abort_install(PKG *pkg_entry);
void  pkg_display_cats(int cats_num);
void  pkg_display_found(int num_pkgs, int pager); 
int   pkg_display_deps(FILE *pipe);
int   pkg_display_deps_full_tree(PKG *pkg_entry, FILE *pipe, int root_pkg, int selected, int is_last);
void  pkg_display_messages(PKG *pkg_entry, FILE *pipe);
void  pkg_free_deps(PKG *deps_entry, PKG *pkg_entry);
void  pkg_finish(void);
int   pkg_find_cats(void);
int   pkg_find_deps(void);
void  pkg_get_deps_info_from_index(int total_pkgs);
void  pkg_install_packages(int install_options);
int   pkg_install_deps(PKG *pkg_entry, int root_pkg, int *display_files);
void  pkg_install_summary(PKG *pkg_entry);
void  pkg_init(void);
void  pkg_insert(PKG *entry, int rdeps);
int   pkg_local_install(int argc, char *argv[], int optind, int options);
void  pkg_remove_extension(PKG *pkg_entry);
int   pkg_remote_install(int argc, char *argv[], int optind, int options);
int   pkg_show_deps(int install_options);
int   is_pkg_installed(PKG *pkg_entry, int subdeps, int total_pkgs);


#endif /* !_PKG_H_ */

==> pkg_add_it-1.3.2.tar.gz: pkg_add_it-1.3.2/pkg.h <==
/*-
 * Copyright (c) 2010  Marin Atanasov Nikolov  <dnaeon@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _PKG_H_
#define _PKG_H_

#ifndef _SYS_QUEUE_H_
#include <sys/queue.h>
#endif

#define LONGLINE		 "#####################################################################\n"

#define PKG_DB_PATH		 "/var/db/pkg"
#define PKG_DISPLAY_FILE	 "+DISPLAY"

#define PKG_EXTENSION		 ".tbz"
#define PKG_FIELDS_SEPARATOR	 "|"

#define PKG_FIELDS		 13

/* package fields */
#define PKG_NAME		 0	 /* package name */
#define PKG_PORT_DIR		 1	 /* package port directory */
#define PKG_INST_PREFIX		 2	 /* package install prefix */
#define PKG_DESC		 3	 /* package description */
#define PKG_DESC_FILE		 4	 /* package description file location */
#define PKG_MAINT		 5	 /* package maintainer */
#define PKG_CAT			 6	 /* package category/path */
#define PKG_BDEPS		 7	 /* package build-deps */
#define PKG_RDEPS		 8	 /* package run-deps */ 
#define PKG_WWW			 9	 /* package web site */
#define PKG_EDEPS		 10	 /* package extract-deps */
#define PKG_PDEPS		 11	 /* package patch-deps */
#define PKG_FDEPS		 12	 /* package fetch-deps */

/* package fields headers */
#define PKG_NAME_HEADER		 "Name: "
#define PKG_PORT_DIR_HEADER	 "Port: "
#define PKG_INST_PREFIX_HEADER	 "Install prefix: "
#define PKG_DESC_HEADER		 "Description: "
#define PKG_DESC_FILE_HEADER	 "Description file: "
#define PKG_MAINT_HEADER	 "Maintainer: "
#define PKG_CAT_HEADER		 "Category: "
#define PKG_BDEPS_HEADER	 "B-Deps: "
#define PKG_RDEPS_HEADER	 "R-Deps: "
#define PKG_WWW_HEADER		 "WWW: "
#define PKG_EDEPS_HEADER	 "E-Deps: "
#define PKG_PDEPS_HEADER	 "P-Deps: "
#define PKG_FDEPS_HEADER	 "F-Deps: "

/* package state flags */
#define PKG_FLAGS_INSTALLED	 0x00000001
#define PKG_FLAGS_INSTALL_RESULT 0x00000002
#define PKG_FLAGS_SELECTED	 0x00000004
#define PKG_FLAGS_COPIED	 0x00000008
#define PKG_FLAGS_ROOT_PKG	 0x00000010

/* indent of package dependencies while listing them in a tree view */ 
#define PKG_DEPS_INDENT		 4
#define PKG_DEPS_INDENT_CHAR     ' '
#define PKG_DEPS_INDENT_LINK	 '|'

/* 
 * stores the information for each package 
 *
 * pkg_fields[] - all data describing a package
 * deps_head    - tail containing the package dependencies
 * pkg_num      - number of packages in the category (used only with the -C option)
 * flags        - stores information about the following package states:
 *		  - package is already installed
 *		  - result from package installation - success or failure
 *		  - package is already selected for install by a previous package
 */ 

typedef struct pkg {
   char	   *pkg_fields[PKG_FIELDS];
   char	    flags;
   unsigned pkg_num; 

   STAILQ_ENTRY(pkg) entries;
   STAILQ_HEAD(, pkg) deps_head;
} PKG;

void  pkg_build_deps_full_tree(PKG *pkg_entry);
void  pkg_choose(int num_pkgs);
int   pkg_deps_abort_install(PKG *pkg_entry);
void  pkg_display_cats(int cats_num);
void  pkg_display_found(int num_pkgs, int pager); 
int   pkg_display_deps(FILE *pipe);
int   pkg_display_deps_full_tree(PKG *pkg_entry, FILE *pipe, int root_pkg, int selected, int is_last);
void  pkg_free_deps(PKG *deps_entry, PKG *pkg_entry);
void  pkg_finish(void);
int   pkg_find_cats(void);
int   pkg_find_deps(void);
void  pkg_get_deps_info_from_index(int total_pkgs);
void  pkg_install_packages(int install_options);
int   pkg_install_deps(PKG *pkg_entry, int root_pkg);
void  pkg_init(void);
void  pkg_insert(PKG *entry, int rdeps);
int   pkg_local_install(int argc, char *argv[], int optind, int options);
void  pkg_remove_extension(PKG *pkg_entry);
int   pkg_remote_install(int argc, char *argv[], int optind, int options);
int   pkg_show_deps(int install_options);
int   is_pkg_installed(PKG *pkg_entry, int set_flag, int total_pkgs);


#endif /* !_PKG_H_ */
